@@ -71,7 +71,7 @@ class PulsarSourceEnumeratorTest extends PulsarTestSuiteBase {
     @ParameterizedTest
     @EnumSource(
             value = SubscriptionType.class,
-            names = {"Failover", "Shared"})
+            names = {"Failover"})
     void startWithDiscoverPartitionsOnce(SubscriptionType subscriptionType) throws Exception {
         Set<String> preexistingTopics = setupPreexistingTopics();
         try (MockSplitEnumeratorContext<PulsarPartitionSplit> context =
@@ -96,7 +96,7 @@ class PulsarSourceEnumeratorTest extends PulsarTestSuiteBase {
     @ParameterizedTest
     @EnumSource(
             value = SubscriptionType.class,
-            names = {"Failover", "Shared"})
+            names = {"Failover"})
     void startWithPeriodicPartitionDiscovery(SubscriptionType subscriptionType) throws Exception {
         Set<String> preexistingTopics = setupPreexistingTopics();
         try (MockSplitEnumeratorContext<PulsarPartitionSplit> context =
@@ -119,7 +119,7 @@ class PulsarSourceEnumeratorTest extends PulsarTestSuiteBase {
     @ParameterizedTest
     @EnumSource(
             value = SubscriptionType.class,
-            names = {"Failover", "Shared"})
+            names = {"Failover"})
     void discoverPartitionsTriggersAssignments(SubscriptionType subscriptionType) throws Throwable {
         Set<String> preexistingTopics = setupPreexistingTopics();
         try (MockSplitEnumeratorContext<PulsarPartitionSplit> context =
@@ -148,7 +148,7 @@ class PulsarSourceEnumeratorTest extends PulsarTestSuiteBase {
     @ParameterizedTest
     @EnumSource(
             value = SubscriptionType.class,
-            names = {"Failover", "Shared"})
+            names = {"Failover"})
     void discoverPartitionsPeriodically(SubscriptionType subscriptionType) throws Throwable {
         String dynamicTopic = "topic3-" + randomAlphabetic(10);
         Set<String> preexistingTopics = setupPreexistingTopics();
@@ -192,7 +192,7 @@ class PulsarSourceEnumeratorTest extends PulsarTestSuiteBase {
     @ParameterizedTest
     @EnumSource(
             value = SubscriptionType.class,
-            names = {"Failover", "Shared"})
+            names = {"Failover"})
     void addSplitsBack(SubscriptionType subscriptionType) throws Throwable {
         Set<String> preexistingTopics = setupPreexistingTopics();
         try (MockSplitEnumeratorContext<PulsarPartitionSplit> context =
@@ -225,7 +225,7 @@ class PulsarSourceEnumeratorTest extends PulsarTestSuiteBase {
     @ParameterizedTest
     @EnumSource(
             value = SubscriptionType.class,
-            names = {"Failover", "Shared"})
+            names = {"Failover"})
     void workWithPreexistingAssignments(SubscriptionType subscriptionType) throws Throwable {
         Set<String> preexistingTopics = setupPreexistingTopics();
         PulsarSourceEnumState preexistingAssignments;
@@ -267,7 +267,7 @@ class PulsarSourceEnumeratorTest extends PulsarTestSuiteBase {
     @ParameterizedTest
     @EnumSource(
             value = SubscriptionType.class,
-            names = {"Failover", "Shared"})
+            names = {"Failover"})
     void snapshotState(SubscriptionType subscriptionType) throws Throwable {
         Set<String> preexistingTopics = setupPreexistingTopics();
         try (MockSplitEnumeratorContext<PulsarPartitionSplit> context =
